function initME = initBattery(stoScale,stoIni,stoPosition,withSOH,sohIni)

if withSOH == 0
    min_np = 8;    % Minimum strings in parallel
    max_np = 80;   % Maximum strings in parallel
    range_np = max_np - min_np;
    
    np = (stoScale/100)*range_np;
    np = np + min_np;
    
    initME.batt = bat([],round(np),withSOH);
else
    tempStoScale = 0;
    
    if stoScale > 25
        if stoScale > 50
            if stoScale > 75
                np = 4;
                tempStoScale = stoScale - 75;
            else
                np = 3;
                tempStoScale = stoScale - 50;
            end
        else
            np = 2;
            tempStoScale = stoScale - 25;
        end
    else
        np = 1;
        tempStoScale = stoScale;
    end
    
    ns = ((tempStoScale-1)*2)+40;
    
    initME.batt = bat(ns,np,withSOH);
end

initME.batt.init = stoIni;

if isempty(sohIni)
    initME.batt.initSOH = 0;
else
    initME.batt.initSOH = sohIni;
end

switch stoPosition  % 1=Primary, 2=Secondary
    case 1
        initME.costB = initME.batt.cost;
        initME.massB = initME.batt.mass;
        
    case 2
        initME.costE = initME.batt.cost;
        initME.massE = initME.batt.mass;
end

end


function bat = bat(ns,np,withSOH)

load batt

cellNominalV = 3.6; %V
cellNominalCap = 2.9; %Ah
cellMaxV = 4.2; %V
cellMinCap = 2.75; %Ah

celldiscrate = 15;
cellchgcrate = celldiscrate/3;

oriSmartCap = 16500; %Wh

orins = round(nanmean(batt.ocv.y)./cellMaxV); % 80
orinp = round(oriSmartCap/nanmean(batt.ocv.y)/cellNominalCap); % 17
%orires = batt.res;
orires = 0.45;

if isempty(ns)
    ns = orins;
end

if isempty(np)
    np = orinp;
end

cellres = (orires / orins) * orinp ;

batt.ocv.cap = (1-batt.ocv.x./100).*(16500/nanmean(batt.ocv.y))./orinp;
batt.ocv.y = batt.ocv.y./orins;

bat.capAh = cellNominalCap * np;
bat.ocv.x = batt.ocv.x;
bat.ocv.y = batt.ocv.y * ns;
bat.res = cellres * ns / np;
bat.ocv.cap = (1-bat.ocv.x./100).*bat.capAh;

bat.capWh = bat.capAh * nanmean(bat.ocv.y);
bat.crateMap = -40:0.01:40;
bat.VtMap = nanmean(bat.ocv.y) - bat.crateMap .* bat.capAh .* bat.res;
bat.effMap = bat.VtMap./nanmean(bat.ocv.y);
bat.effMap(bat.effMap>1) = 1./bat.effMap(bat.effMap>1);

bat.disCrateMap = 0:0.01:40;
bat.disPowVtMap = nanmean(bat.ocv.y) .* bat.capAh .* bat.disCrateMap - (bat.capAh .* bat.disCrateMap).^2 * bat.res;
bat.disPowVocvMap = nanmean(bat.ocv.y) .* bat.capAh .* bat.disCrateMap;
bat.disEffMap = bat.disPowVtMap./bat.disPowVocvMap;
bat.chgCrateMap = 0:0.01:40;
bat.chgPowVtMap = nanmean(bat.ocv.y) .* bat.capAh .* bat.chgCrateMap + (bat.capAh .* bat.chgCrateMap).^2 * bat.res;
bat.chgPowVocvMap = nanmean(bat.ocv.y) .* bat.capAh .* bat.chgCrateMap;
bat.chgEffMap = bat.chgPowVocvMap./bat.chgPowVtMap;

bat.disPow = bat.disPowVtMap(find(bat.disEffMap>0.8,1,'last')-1);
bat.chgPow = bat.disPow/2;
bat.disCrate = bat.disCrateMap(find(bat.disEffMap>0.5,1,'last')-1);
bat.chgCrate = bat.disCrate/2;
bat.pow = bat.disPow;

if withSOH == 1
    bat.capWh=3.7*ns*33.1*np;
    bat.ns = ns;
    bat.np = np;
    bat.mass = ns * np * 3.8/4;
    bat.cost = bat.capWh * 600/1000; % USD from Max Groff's thesis page 68;
else
    bat.mass = ns * np * 45 * 2.5 / 1000;
    bat.cost = 22 * bat.pow / 1000 + 700 * bat.capWh / 1000 + 680;
end

end