function initME = initFlywheel(stoScale)

width_min = 50;  % Minimum width (mm)
width_max = 200; % Maximum width (mm)
width_mid = 100; % Width of Flybrid's system (mm)
d_min = 100;     % Minimum outer diameter (mm)
d_max = 300;     % Maximum outer diameter (mm)
d_mid = 200;     % Outer diameter of Flybrid's system (mm)

widthArray1 = linspace(width_min,width_mid,50);
widthArray2 = linspace(width_mid,width_max,51);
widthArray2 = widthArray2(2:length(widthArray2));
widthArray = [widthArray1 widthArray2];

dArray1 = linspace(d_min,d_mid,50);
dArray2 = linspace(d_mid,d_max,51);
dArray2 = dArray2(2:length(dArray2));
dArray = [dArray1 dArray2];

width = widthArray(stoScale);   % Flywheel width (mm)
d_outer = dArray(stoScale);     % Outer diameter (mm)
d_inner = d_outer*(260/360);    % Inner diamater (mm)

initME.flywheel = flyWheel(width,d_outer,d_inner,stoScale);

initME.costE = initME.flywheel.cost;
initME.massE = initME.flywheel.mass;
end


function flywheel = flyWheel(width,d_outer,d_inner,stoScale)

flywheel.width = width;
flywheel.diameter = d_outer;

width = width * 0.001; % mm to m
d_outer = d_outer * 0.001; % mm to m
d_inner = d_inner * 0.001; % mm to m

r_outer = d_outer/2;  % flywheel outer radius (m)
r_inner = d_inner/2;  % flywheel inner radius (m)
% rho = 7870;           % Density (kg/m^3) - Cast iron
rho = 2710;           % Density (kg/m^3) - Aluminium T6 (www.matweb.com)
mass = pi * (r_outer^2 - r_inner^2) * width * rho;
flywheel.inertia = 0.5 * mass * (r_outer^2 + r_inner^2);

flywheel.lower_limit = 1000;  % rad/s
flywheel.upper_limit = 6000;  % rad/s

flywheel.cost = ((4500-2500)*(stoScale/100))+2500;      % $3000 from MSc group project, $2500 to $4500 from "A comparison of high-speed flywheels, batteries, and ultracapacitors on the bases of cost and fuel economy as the energy storage system in a fuel cell based hybrid electric vehicle"
flywheel.mass = mass + 10; % extra 10kg for enclosure,

% From SAE Paper 2009-01-2868:
% Power: 60kW
% System Weight: 25kg
% Flywheel Weight: 5kg
% CVT Weight: 5kg
% Flywheel Diameter: 200mm
% Flywheel Length: 100mm
% Flywheel Inertia: 0.026kgm^2
% Max speed: 64,500rpm

% Flybrid Presentation
% Energy: 150kJ
% Power: 15kW

end